@@ -13,10 +13,8 @@ using namespace Rcpp;
 namespace bg = boost::geometry;
 namespace bgm = bg::model;
 
-
-
 void addLonLatToWKTStream(std::ostringstream& os, float lon, float lat ) {
-  os << lon << " " << lat;
+  os << std::to_string(lon) << " " << std::to_string(lat);
 }
 
 void geom_type(const char *cls, int *tp = NULL) {
